@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -20,19 +20,17 @@ sub command_names { return qw(log history) }
 #------------------------------------------------------------------------------
 
 sub opt_spec {
-    my ($self, $app) = @_;
+    my ( $self, $app ) = @_;
 
-    return (
-        [ 'stack|s=s' => 'Show history for this stack' ],
-    );
+    return ( [ 'stack|s=s' => 'Show history for this stack' ], );
 }
 
 #------------------------------------------------------------------------------
 
 sub validate_args {
-    my ($self, $opts, $args) = @_;
+    my ( $self, $opts, $args ) = @_;
 
-    $self->usage_error('Multiple arguments are not allowed') if @{ $args } > 1;
+    $self->usage_error('Multiple arguments are not allowed') if @{$args} > 1;
 
     $opts->{stack} = $args->[0] if $args->[0];
 
@@ -57,7 +55,7 @@ App::Pinto::Command::log - show the revision logs of a stack
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 SYNOPSIS
 
