@@ -11,27 +11,25 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
 sub opt_spec {
-    my ($self, $app) = @_;
+    my ( $self, $app ) = @_;
 
-    return (
-        [ 'sleep=i' => 'seconds to sleep before exiting' ],
-    );
+    return ( [ 'sleep=i' => 'seconds to sleep before exiting' ], );
 }
 
 #------------------------------------------------------------------------------
 
 sub validate_args {
-    my ($self, $opts, $args) = @_;
+    my ( $self, $opts, $args ) = @_;
 
-    $self->SUPER::validate_args($opts, $args);
+    $self->SUPER::validate_args( $opts, $args );
 
     $self->usage_error('Sleep time must be positive integer')
-      if defined $opts->{sleep} && $opts->{sleep} < 1;
+        if defined $opts->{sleep} && $opts->{sleep} < 1;
 
     return 1;
 }
@@ -53,7 +51,7 @@ App::Pinto::Command::nop - do nothing
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 SYNOPSIS
 
