@@ -4,7 +4,7 @@ package Pinto::Action::List;
 
 use Moose;
 use MooseX::StrictConstructor;
-use MooseX::MarkAsMethods (autoclean => 1);
+use MooseX::MarkAsMethods ( autoclean => 1 );
 use MooseX::Types::Moose qw(HashRef Str Bool);
 
 use Pinto::Constants qw(:color);
@@ -12,7 +12,7 @@ use Pinto::Types qw(AuthorID StackName StackDefault StackObject);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -21,49 +21,43 @@ extends qw( Pinto::Action );
 #------------------------------------------------------------------------------
 
 has stack => (
-    is        => 'ro',
-    isa       => StackName | StackDefault | StackObject,
-    default   => undef,
+    is      => 'ro',
+    isa     => StackName | StackDefault | StackObject,
+    default => undef,
 );
 
-
 has pinned => (
-    is     => 'ro',
-    isa    => Bool,
+    is  => 'ro',
+    isa => Bool,
 );
 
-
 has author => (
-    is     => 'ro',
-    isa    => AuthorID,
+    is  => 'ro',
+    isa => AuthorID,
 );
 
-
 has packages => (
-    is     => 'ro',
-    isa    => Str,
+    is  => 'ro',
+    isa => Str,
 );
 
-
 has distributions => (
-    is     => 'ro',
-    isa    => Str,
+    is  => 'ro',
+    isa => Str,
 );
 
-
 has format => (
-    is        => 'ro',
-    isa       => Str,
-    default   => '[%F] %-40p %12v %a/%f',
-    lazy      => 1,
+    is      => 'ro',
+    isa     => Str,
+    default => '[%F] %-40p %12v %a/%f',
+    lazy    => 1,
 );
 
-
 has where => (
-    is       => 'ro',
-    isa      => HashRef,
-    builder  => '_build_where',
-    lazy     => 1,
+    is      => 'ro',
+    isa     => HashRef,
+    builder => '_build_where',
+    lazy    => 1,
 );
 
 #------------------------------------------------------------------------------
@@ -72,22 +66,22 @@ sub _build_where {
     my ($self) = @_;
 
     my $where = {};
-    my $stack = $self->repo->get_stack($self->stack);
-    $where = {revision => $stack->head->id};
+    my $stack = $self->repo->get_stack( $self->stack );
+    $where = { revision => $stack->head->id };
 
-    if (my $pkg_name = $self->packages) {
-        $where->{'package.name'} = { like => "%$pkg_name%" }
+    if ( my $pkg_name = $self->packages ) {
+        $where->{'package.name'} = { like => "%$pkg_name%" };
     }
 
-    if (my $dist_name = $self->distributions) {
+    if ( my $dist_name = $self->distributions ) {
         $where->{'distribution.archive'} = { like => "%$dist_name%" };
     }
 
-    if (my $author = $self->author) {
+    if ( my $author = $self->author ) {
         $where->{'distribution.author'} = uc $author;
     }
 
-    if (my $pinned = $self->pinned) {
+    if ( my $pinned = $self->pinned ) {
         $where->{is_pinned} = 1;
     }
 
@@ -100,8 +94,8 @@ sub execute {
     my ($self) = @_;
 
     my $where = $self->where;
-    my $attrs = {prefetch => [ qw(revision package distribution) ]};
-    my $rs    = $self->repo->db->schema->search_registration($where, $attrs);
+    my $attrs = { prefetch => [qw(revision package distribution)] };
+    my $rs    = $self->repo->db->schema->search_registration( $where, $attrs );
 
     # I'm not sure why, but the results appear to come out sorted by
     # package name, even though I haven't specified how to order them.
@@ -110,13 +104,14 @@ sub execute {
     # in the registration table.
 
     while ( my $reg = $rs->next ) {
-        my $string = $reg->to_string($self->format);
+        my $string = $reg->to_string( $self->format );
 
-        my $color =   $reg->is_pinned              ? $PINTO_COLOR_1
-                    : $reg->distribution->is_local ? $PINTO_COLOR_0 
-                    : undef;
+        my $color =
+              $reg->is_pinned              ? $PINTO_COLOR_1
+            : $reg->distribution->is_local ? $PINTO_COLOR_0
+            :                                undef;
 
-        $self->show($string, {color => $color});
+        $self->show( $string, { color => $color } );
     }
 
     return $self->result;
@@ -144,7 +139,7 @@ Pinto::Action::List - List the contents of a stack
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 AUTHOR
 
