@@ -5,14 +5,15 @@ package Pinto::Action::Stacks;
 use Moose;
 use MooseX::StrictConstructor;
 use MooseX::Types::Moose qw(Str);
-use MooseX::MarkAsMethods (autoclean => 1);
+use MooseX::MarkAsMethods ( autoclean => 1 );
 
 use List::Util qw(max);
 
 use Pinto::Constants qw(:color);
+
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -21,8 +22,8 @@ extends 'Pinto::Action';
 #------------------------------------------------------------------------------
 
 has format => (
-    is      => 'ro',
-    isa     => Str,
+    is  => 'ro',
+    isa => Str,
 );
 
 #------------------------------------------------------------------------------
@@ -30,22 +31,23 @@ has format => (
 sub execute {
     my ($self) = @_;
 
-    my @stacks = sort {$a cmp $b} $self->repo->get_all_stacks;
+    my @stacks = sort { $a cmp $b } $self->repo->get_all_stacks;
 
-	my $max_name = max(map { length($_->name) } @stacks)           || 0;
-	my $max_user = max(map { length($_->head->username) } @stacks) || 0;
+    my $max_name = max( map { length( $_->name ) } @stacks )           || 0;
+    my $max_user = max( map { length( $_->head->username ) } @stacks ) || 0;
 
-	my $format = $self->format || "%M%L %-${max_name}k  %u  %-{$max_user}j  %i: %{40}T";
+    my $format = $self->format || "%M%L %-${max_name}k  %u  %-{$max_user}j  %i: %{40}T";
 
-	for my $stack (@stacks) {
-		my $string = $stack->to_string($format);
+    for my $stack (@stacks) {
+        my $string = $stack->to_string($format);
 
-		my $color =   $stack->is_default ? $PINTO_COLOR_0 
-		            : $stack->is_locked  ? $PINTO_COLOR_2 : undef;
-
-		$self->show($string, {color => $color}); 
-	}
+        my $color =
+              $stack->is_default ? $PINTO_COLOR_0
+            : $stack->is_locked  ? $PINTO_COLOR_2
+            :                      undef;
 
+        $self->show( $string, { color => $color } );
+    }
 
     return $self->result;
 }
@@ -72,7 +74,7 @@ Pinto::Action::Stacks - List known stacks in the repository
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 AUTHOR
 
