@@ -11,7 +11,7 @@ use base 'Exporter';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -43,12 +43,12 @@ Readonly our @EXPORT_OK => qw(
     $PINTO_REVISION_ID_REGEX
 );
 
-Readonly our %EXPORT_TAGS => ( 
+Readonly our %EXPORT_TAGS => (
     all    => \@EXPORT_OK,
-    color  => [ grep { m/COLOR/x }  @EXPORT_OK ],
-    server => [ grep { m/SERVER/x } @EXPORT_OK ],
-    regex  => [ grep { m/REGEX/x }  @EXPORT_OK ],
-    lock   => [ grep { m/LOCK/x }   @EXPORT_OK ],
+    color  => [ grep {m/COLOR/x} @EXPORT_OK ],
+    server => [ grep {m/SERVER/x} @EXPORT_OK ],
+    regex  => [ grep {m/REGEX/x} @EXPORT_OK ],
+    lock   => [ grep {m/LOCK/x} @EXPORT_OK ],
 );
 
 #------------------------------------------------------------------------------
@@ -57,8 +57,7 @@ Readonly our $PINTO_SERVER_DEFAULT_HOST => 'localhost';
 
 Readonly our $PINTO_SERVER_DEFAULT_PORT => 3111;
 
-Readonly our $PINTO_SERVER_DEFAULT_ROOT  =>
-  "http://$PINTO_SERVER_DEFAULT_HOST:$PINTO_SERVER_DEFAULT_PORT";
+Readonly our $PINTO_SERVER_DEFAULT_ROOT => "http://$PINTO_SERVER_DEFAULT_HOST:$PINTO_SERVER_DEFAULT_PORT";
 
 #------------------------------------------------------------------------------
 
@@ -72,7 +71,7 @@ Readonly our $PINTO_SERVER_PROGRESS_MESSAGE => "${PINTO_SERVER_DIAG_PREFIX}. ##"
 
 #------------------------------------------------------------------------------
 
-Readonly our $PINTO_DEFAULT_COLORS => [ qw(green yellow red) ];
+Readonly our $PINTO_DEFAULT_COLORS => [qw(green yellow red)];
 
 Readonly our $PINTO_COLOR_0 => 0;
 Readonly our $PINTO_COLOR_1 => 1;
@@ -85,12 +84,12 @@ Readonly our $PINTO_LOCK_TYPE_EXCLUSIVE => 'EX';
 
 #------------------------------------------------------------------------------
 
-Readonly our $PINTO_STACK_NAME_ALL  => '%';
+Readonly our $PINTO_STACK_NAME_ALL => '%';
 
 #------------------------------------------------------------------------------
 
-Readonly my $PINTO_ALPHANUMERIC_REGEX       => qr{^ [a-zA-Z0-9-_]+ $}x;
-Readonly my $PINTO_HEXADECIMAL_UUID_REGEX   => qr{^ [a-f0-9-]+     $}x;
+Readonly my $PINTO_ALPHANUMERIC_REGEX     => qr{^ [a-zA-Z0-9-_]+ $}x;
+Readonly my $PINTO_HEXADECIMAL_UUID_REGEX => qr{^ [a-f0-9-]+     $}x;
 
 Readonly our $PINTO_AUTHOR_REGEX        => qr/^ [A-Z]{2} [-A-Z0-9]* $/x;
 Readonly our $PINTO_USERNAME_REGEX      => $PINTO_ALPHANUMERIC_REGEX;
@@ -115,7 +114,7 @@ Pinto::Constants - Constants used across the Pinto utilities
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 AUTHOR
 
