@@ -5,7 +5,7 @@ package Pinto::Difference;
 use Moose;
 use MooseX::StrictConstructor;
 use MooseX::Types::Moose qw(ArrayRef);
-use MooseX::MarkAsMethods (autoclean => 1);
+use MooseX::MarkAsMethods ( autoclean => 1 );
 
 use Pinto::Util qw(itis);
 
@@ -13,7 +13,7 @@ use overload ( q{""} => 'to_string' );
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -23,41 +23,43 @@ has left => (
     required => 1,
 );
 
-
 has right => (
     is       => 'ro',
     isa      => 'Pinto::Schema::Result::Revision',
     required => 1,
 );
 
-
 has diffs => (
-    traits   => [ qw(Array) ],
-    handles  => {diffs => 'elements'},
-    isa      => ArrayRef['Pinto::DifferenceEntry'],
+    traits   => [qw(Array)],
+    handles  => { diffs => 'elements' },
+    isa      => ArrayRef ['Pinto::DifferenceEntry'],
     builder  => '_build_diffs',
     init_arg => undef,
     lazy     => 1,
 );
 
-
 has additions => (
-    traits   => [ qw(Array) ],
-    handles  => {additions => 'elements'},
-    isa      => ArrayRef['Pinto::Schema::Result::Registration'],
-    default  => sub { [ map  { $_->registration } 
-                        grep {$_->op eq '+'} $_[0]->diffs ] }, 
+    traits  => [qw(Array)],
+    handles => { additions => 'elements' },
+    isa     => ArrayRef ['Pinto::Schema::Result::Registration'],
+    default => sub {
+        [   map  { $_->registration }
+            grep { $_->op eq '+' } $_[0]->diffs
+        ];
+    },
     init_arg => undef,
     lazy     => 1,
 );
 
-
 has deletions => (
-    traits   => [ qw(Array) ],
-    handles  => {deletions => 'elements'},
-    isa      => ArrayRef['Pinto::Schema::Result::Registration'],
-    default  => sub { [ map  { $_->registration } 
-                        grep {$_->op eq '-'} $_[0]->diffs ] }, 
+    traits  => [qw(Array)],
+    handles => { deletions => 'elements' },
+    isa     => ArrayRef ['Pinto::Schema::Result::Registration'],
+    default => sub {
+        [   map  { $_->registration }
+            grep { $_->op eq '-' } $_[0]->diffs
+        ];
+    },
     init_arg => undef,
     lazy     => 1,
 );
@@ -69,11 +71,11 @@ around BUILDARGS => sub {
     my $class = shift;
     my $args  = $class->$orig(@_);
 
-    # The left and right attributes can also be Stack objects.  
+    # The left and right attributes can also be Stack objects.
     # In those cases, we just use the head revision of the Stack
 
-    for my $side ( qw(left right) ) {
-        if ($args->{$side}->isa('Pinto::Schema::Result::Stack')) {
+    for my $side (qw(left right)) {
+        if ( $args->{$side}->isa('Pinto::Schema::Result::Stack') ) {
             $args->{$side} = $args->{$side}->head;
         }
     }
@@ -86,8 +88,7 @@ around BUILDARGS => sub {
 sub _build_diffs {
     my ($self) = @_;
 
-
-    # We want to find the registrations that are "different" in either 
+    # We want to find the registrations that are "different" in either
     # side.  Two registrations are the same if they have the same values in
     # the package, distribution, and is_pinned columns.  So we use these
     # columns to construct the keys of a hash.  The value is the id of
@@ -97,28 +98,28 @@ sub _build_diffs {
 
     my $cb = sub {
         my $value = $_[0]->id;
-        my $key   = join '|', map {$_[0]->get_column($_)} @fields;
-        return ($key => $value);
+        my $key = join '|', map { $_[0]->get_column($_) } @fields;
+        return ( $key => $value );
     };
 
-    my $attrs = {select => ['id', @fields]};
-    my %left  = $self->left->registrations({},  $attrs)->as_hash($cb);
-    my %right = $self->right->registrations({}, $attrs)->as_hash($cb);
+    my $attrs = { select => [ 'id', @fields ] };
+    my %left = $self->left->registrations( {}, $attrs )->as_hash($cb);
+    my %right = $self->right->registrations( {}, $attrs )->as_hash($cb);
 
     # Now that we have hashes representing the left and right, we use
     # the keys as "sets" and compute the difference between them.  Keys
     # present on the right but not on the left have been added.  And
     # those present on left but not on the right have been deleted.
 
-    my @add_ids = @right{ grep { not exists $left{$_}  } keys %right };
-    my @del_ids = @left{  grep { not exists $right{$_} } keys %left  };
+    my @add_ids = @right{ grep { not exists $left{$_} } keys %right };
+    my @del_ids = @left{ grep  { not exists $right{$_} } keys %left };
 
     # Now we have the ids of all the registrations that were added or
     # deleted between the left and right revisions.  We use those ids to
-    # requery the database and construct full objects for each of them.  
+    # requery the database and construct full objects for each of them.
 
-    my @adds = $self->_create_entries('+', $self->right, \@add_ids);
-    my @dels = $self->_create_entries('-', $self->left,  \@del_ids);
+    my @adds = $self->_create_entries( '+', $self->right, \@add_ids );
+    my @dels = $self->_create_entries( '-', $self->left,  \@del_ids );
 
     # Strictly speaking, the registrations are an unordered list.  But
     # the diff is more readable if we group registrations together by
@@ -132,26 +133,26 @@ sub _build_diffs {
 #------------------------------------------------------------------------------
 
 sub _create_entries {
-    my ($self, $type, $side, $ids) = @_;
+    my ( $self, $type, $side, $ids ) = @_;
 
     # The number of ids is potentially pretty big (1000's) and we
     # can't use that many values in an IN clause.  So we insert all
     # those ids into a temporary table.
 
     my $tmp_tbl = "__diff_${$}__";
-    my $dbh = $self->right->result_source->schema->storage->dbh;
+    my $dbh     = $self->right->result_source->schema->storage->dbh;
     $dbh->do("CREATE TEMP TABLE $tmp_tbl (reg INTEGER NOT NULL)");
 
     my $sth = $dbh->prepare("INSERT INTO $tmp_tbl VALUES( ? )");
-    $sth->execute($_) for @{ $ids };
+    $sth->execute($_) for @{$ids};
 
     # Now fetch the actual Registration objects (with all their
     # related objects) for each id in the temp table.  Finally,
     # map all the Registrations into DifferenceEntry objects.
 
-    my $where   = {'me.id' => {in => \"SELECT reg from $tmp_tbl"}};
+    my $where   = { 'me.id' => { in => \"SELECT reg from $tmp_tbl" } };
     my $reg_rs  = $side->registrations($where)->with_distribution->with_package;
-    my @entries = map { Pinto::DifferenceEntry->new(op => $type, registration => $_) } $reg_rs->all;
+    my @entries = map { Pinto::DifferenceEntry->new( op => $type, registration => $_ ) } $reg_rs->all;
 
     $dbh->do("DROP TABLE $tmp_tbl");
 
@@ -161,9 +162,9 @@ sub _create_entries {
 #------------------------------------------------------------------------------
 
 sub foreach {
-    my ($self, $cb) = @_;
+    my ( $self, $cb ) = @_;
 
-    $cb->($_) for $self->diffs; 
+    $cb->($_) for $self->diffs;
 
     return $self;
 }
@@ -187,31 +188,30 @@ package Pinto::DifferenceEntry;
 
 use Moose;
 use MooseX::StrictConstructor;
-use MooseX::MarkAsMethods (autoclean => 1);
+use MooseX::MarkAsMethods ( autoclean => 1 );
 use MooseX::Types::Moose qw(Str);
 
 use overload (
-    q{""}    =>  'to_string',
-    'cmp'    =>  'string_compare',
+    q{""} => 'to_string',
+    'cmp' => 'string_compare',
 );
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
-has op  => (
-    is       => 'ro', 
-    isa      => Str, 
+has op => (
+    is       => 'ro',
+    isa      => Str,
     required => 1
 );
 
-
 has registration => (
-    is        => 'ro', 
-    isa       => 'Pinto::Schema::Result::Registration', 
-    required  => 1,
+    is       => 'ro',
+    isa      => 'Pinto::Schema::Result::Registration',
+    required => 1,
 );
 
 #------------------------------------------------------------------------------
@@ -226,10 +226,9 @@ sub to_string {
 #------------------------------------------------------------------------------
 
 sub string_compare {
-    my ($self, $other) = @_;
+    my ( $self, $other ) = @_;
 
-    return ( $self->registration->distribution->name 
-             cmp $other->registration->distribution->name ); 
+    return ( $self->registration->distribution->name cmp $other->registration->distribution->name );
 }
 
 #------------------------------------------------------------------------------
@@ -253,7 +252,7 @@ Pinto::Difference - Compute difference between two revisions
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 AUTHOR
 
