@@ -4,30 +4,29 @@ package Pinto::IndexCache;
 
 use Moose;
 use MooseX::StrictConstructor;
-use MooseX::MarkAsMethods (autoclean => 1);
+use MooseX::MarkAsMethods ( autoclean => 1 );
 
 use Package::Locator;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #-------------------------------------------------------------------------------
 
 has repo => (
-   is         => 'ro',
-   isa        => 'Pinto::Repository',
-   weak_ref   => 1,
-   required   => 1,
+    is       => 'ro',
+    isa      => 'Pinto::Repository',
+    weak_ref => 1,
+    required => 1,
 );
 
-
 has locator => (
-    is         => 'ro',
-    isa        => 'Package::Locator',
-    handles    => [ qw(clear_cache) ],
-    builder    => '_build_locator',
-    lazy       => 1,
+    is      => 'ro',
+    isa     => 'Package::Locator',
+    handles => [qw(clear_cache)],
+    builder => '_build_locator',
+    lazy    => 1,
 );
 
 #-------------------------------------------------------------------------------
@@ -37,8 +36,10 @@ sub _build_locator {
 
     my @urls      = $self->repo->config->sources_list;
     my $cache_dir = $self->repo->config->cache_dir;
-    my $locator   = Package::Locator->new(repository_urls => \@urls,
-                                          cache_dir       => $cache_dir);
+    my $locator   = Package::Locator->new(
+        repository_urls => \@urls,
+        cache_dir       => $cache_dir
+    );
 
     return $locator;
 }
@@ -46,7 +47,7 @@ sub _build_locator {
 #-------------------------------------------------------------------------------
 
 sub locate {
-    my ($self, @args) = @_;
+    my ( $self, @args ) = @_;
 
     return $self->locator->locate(@args);
 }
@@ -60,7 +61,7 @@ sub contents {
     for my $index ( $self->locator->indexes() ) {
         for my $dist ( values %{ $index->distributions() } ) {
             next if exists $seen{ $dist->{path} };
-            $dist->{packages} ||= []; # Prevent possible undef
+            $dist->{packages} ||= [];    # Prevent possible undef
             delete $_->{distribution} for @{ $dist->{packages} };
             $seen{ $dist->{path} } = $dist;
         }
@@ -92,7 +93,7 @@ Pinto::IndexCache - Manages indexes files from upstream repositories
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 AUTHOR
 
