@@ -4,22 +4,22 @@ package Pinto::Migrator;
 
 use Moose;
 use MooseX::StrictConstructor;
-use MooseX::MarkAsMethods (autoclean => 1);
+use MooseX::MarkAsMethods ( autoclean => 1 );
 
 use Pinto::Types qw(Dir);
 use Pinto::Repository;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
 has root => (
-    is       => 'ro',
-    isa      => Dir,
-    default  => $ENV{PINTO_REPOSITORY_ROOT},
-    coerce   => 1,
+    is      => 'ro',
+    isa     => Dir,
+    default => $ENV{PINTO_REPOSITORY_ROOT},
+    coerce  => 1,
 );
 
 #------------------------------------------------------------------------------
@@ -27,20 +27,19 @@ has root => (
 sub migrate {
     my ($self) = @_;
 
-    my $repo = Pinto::Repository->new(root => $self->root);
+    my $repo = Pinto::Repository->new( root => $self->root );
 
     my $repo_version = $repo->get_version;
     my $code_version = $Pinto::Repository::REPOSITORY_VERSION;
 
-    die "This repository is too old to migrate.\n" .
-        "Contact thaljef\@cpan.org for a migration plan.\n"
-      if not $repo_version;
+    die "This repository is too old to migrate.\n" . "Contact thaljef\@cpan.org for a migration plan.\n"
+        if not $repo_version;
 
     die "This repository is already up to date.\n"
-      if $repo_version == $code_version;
+        if $repo_version == $code_version;
 
     die "This repository too new.  Upgrade Pinto instead.\n"
-      if $repo_version > $code_version;
+        if $repo_version > $code_version;
 
     die "Migration is not implemented yet\n";
 }
@@ -67,7 +66,7 @@ Pinto::Migrator - Migrate an existing repository to a new version
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 AUTHOR
 
