@@ -5,7 +5,7 @@ package Pinto::PackageExtractor;
 use Moose;
 use MooseX::StrictConstructor;
 use MooseX::Types::Moose qw(HashRef Bool);
-use MooseX::MarkAsMethods (autoclean => 1);
+use MooseX::MarkAsMethods ( autoclean => 1 );
 
 use Try::Tiny;
 use Dist::Metadata;
@@ -18,7 +18,7 @@ use Pinto::ArchiveUnpacker;
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -29,29 +29,26 @@ has archive => (
     coerce   => 1,
 );
 
-
 has unpacker => (
     is       => 'ro',
     isa      => 'Pinto::ArchiveUnpacker',
-    default  => sub { Pinto::ArchiveUnpacker->new(archive => $_[0]->archive) }, 
+    default  => sub { Pinto::ArchiveUnpacker->new( archive => $_[0]->archive ) },
     init_arg => undef,
     lazy     => 1,
 );
 
-
 has work_dir => (
     is       => 'ro',
     isa      => Dir,
-    default  => sub { $_[0]->unpacker->unpack }, 
+    default  => sub { $_[0]->unpacker->unpack },
     init_arg => undef,
     lazy     => 1,
 );
 
-
 has dm => (
     is       => 'ro',
     isa      => 'Dist::Metadata',
-    default  => sub { Dist::Metadata->new(dir => $_[0]->work_dir, include_inner_packages => 1) },
+    default  => sub { Dist::Metadata->new( dir => $_[0]->work_dir, include_inner_packages => 1 ) },
     init_arg => undef,
     lazy     => 1,
 );
@@ -65,26 +62,32 @@ sub provides {
     debug "Extracting packages provided by archive $archive";
 
     my $mod_info = try {
+
         # Some modules get their VERSION by loading some other
         # module from lib/.  So make sure that lib/ is in @INC
         my $lib_dir = $self->work_dir->subdir('lib');
-        local @INC = ($lib_dir->stringify, @INC);
+        local @INC = ( $lib_dir->stringify, @INC );
 
-        $self->dm->module_info( {checksum => 'sha256'} );   
+        $self->dm->module_info( { checksum => 'sha256' } );
     }
-    catch { 
-         throw "Unable to extract packages from $archive: $_" 
+    catch {
+        throw "Unable to extract packages from $archive: $_";
     };
 
     my @provides;
-    for my $pkg_name ( sort keys %{ $mod_info } ) {
+    for my $pkg_name ( sort keys %{$mod_info} ) {
 
-        my $info = $mod_info->{$pkg_name};
+        my $info    = $mod_info->{$pkg_name};
         my $pkg_ver = version->parse( $info->{version} );
         debug "Archive $archive provides: $pkg_name-$pkg_ver";
 
-        push @provides, { name => $pkg_name,     version => $pkg_ver, 
-                          file => $info->{file}, sha256  => $info->{sha256} };
+        push @provides,
+            {
+            name    => $pkg_name,
+            version => $pkg_ver,
+            file    => $info->{file},
+            sha256  => $info->{sha256}
+            };
     }
 
     @provides = $self->__apply_workarounds if @provides == 0;
@@ -100,21 +103,20 @@ sub requires {
     my $archive = $self->archive;
     debug "Extracting packages required by archive $archive";
 
-    my $prereqs_meta = try   { $self->dm->meta->prereqs }
-                       catch { throw "Unable to extract prereqs from $archive: $_" };
+    my $prereqs_meta = try { $self->dm->meta->prereqs } catch { throw "Unable to extract prereqs from $archive: $_" };
 
     my @prereqs;
-    for my $phase ( qw( develop configure build test runtime ) ) {
+    for my $phase (qw( develop configure build test runtime )) {
 
-        my $prereqs_for_phase = $prereqs_meta->{$phase} || {};
+        my $prereqs_for_phase = $prereqs_meta->{$phase}        || {};
         my $required_prereqs  = $prereqs_for_phase->{requires} || {};
 
-        for my $pkg_name (sort keys %{ $required_prereqs }) {
+        for my $pkg_name ( sort keys %{$required_prereqs} ) {
 
             my $pkg_ver = version->parse( $required_prereqs->{$pkg_name} );
             debug "Archive $archive requires ($phase): $pkg_name-$pkg_ver";
 
-            my $struct = {phase => $phase, name => $pkg_name, version => $pkg_ver};
+            my $struct = { phase => $phase, name => $pkg_name, version => $pkg_ver };
             push @prereqs, $struct;
         }
     }
@@ -130,27 +132,25 @@ sub metadata {
     my $archive = $self->archive;
     debug "Extracting metadata from archive $archive";
 
-    my $metadata =   try { $self->dm->meta }
-                   catch { throw "Unable to extract metadata from $archive: $_" };
+    my $metadata = try { $self->dm->meta } catch { throw "Unable to extract metadata from $archive: $_" };
 
     return $metadata;
 }
 
 #-----------------------------------------------------------------------------
-# HACK: The common-sense and FCGI distributions generate the .pm file at build 
-# time.  It relies on an unusual feature of PAUSE that scans the __DATA__ 
+# HACK: The common-sense and FCGI distributions generate the .pm file at build
+# time.  It relies on an unusual feature of PAUSE that scans the __DATA__
 # section of .PM files for potential packages.  Module::Metdata doesn't have
 # that feature, so to us, it appears that these distributions contain no packages.
 # I've asked the authors to use the "provides" field of the META file so
-# that other tools can discover the packages in the distribution, but then have 
-# not done so.  So we work around it by just assuming the distribution contains a 
+# that other tools can discover the packages in the distribution, but then have
+# not done so.  So we work around it by just assuming the distribution contains a
 # package named "common::sense" or "FCGI".
 
-
 sub __apply_workarounds {
     my ($self) = @_;
 
-    return $self->__common_sense_workaround 
+    return $self->__common_sense_workaround
         if $self->archive->basename =~ m/^ common-sense /x;
 
     return $self->__fcgi_workaround
@@ -166,10 +166,12 @@ sub __apply_workarounds {
 sub __common_sense_workaround {
     my ($self) = @_;
 
-    my ($version) = ($self->archive->basename =~ m/common-sense- ([\d_.]+) \.tar\.gz/x);
+    my ($version) = ( $self->archive->basename =~ m/common-sense- ([\d_.]+) \.tar\.gz/x );
 
-    return { name => 'common::sense',
-             version => version->parse($version) };
+    return {
+        name    => 'common::sense',
+        version => version->parse($version)
+    };
 }
 
 #-----------------------------------------------------------------------------
@@ -179,10 +181,12 @@ sub __common_sense_workaround {
 sub __fcgi_workaround {
     my ($self) = @_;
 
-    my ($version) = ($self->archive->basename =~ m/FCGI- ([\d_.]+) \.tar\.gz/x);
+    my ($version) = ( $self->archive->basename =~ m/FCGI- ([\d_.]+) \.tar\.gz/x );
 
-    return { name => 'FCGI',
-             version => version->parse($version) };
+    return {
+        name    => 'FCGI',
+        version => version->parse($version)
+    };
 }
 
 #-----------------------------------------------------------------------------
@@ -207,7 +211,7 @@ Pinto::PackageExtractor - Extract packages provided/required by a distribution a
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 AUTHOR
 
