@@ -4,7 +4,7 @@ package Pinto::Role::Committable;
 
 use Moose::Role;
 use MooseX::Types::Moose qw(Bool Str);
-use MooseX::MarkAsMethods (autoclean => 1);
+use MooseX::MarkAsMethods ( autoclean => 1 );
 
 use Try::Tiny;
 
@@ -15,7 +15,7 @@ use Pinto::Util qw(is_interactive throw is_blank is_not_blank);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -23,13 +23,12 @@ with qw(Pinto::Role::Plated);
 
 #------------------------------------------------------------------------------
 
-has stack   => (
+has stack => (
     is      => 'ro',
     isa     => StackName | StackDefault | StackObject,
     writer  => '_set_stack',
     default => undef,
-);  
-
+);
 
 has dry_run => (
     is      => 'ro',
@@ -37,26 +36,23 @@ has dry_run => (
     default => 0,
 );
 
-
 has message => (
     is        => 'ro',
     isa       => Str,
     predicate => 'has_message',
 );
 
-
 has use_default_message => (
-    is         => 'ro',
-    isa        => Bool,
-    default    => 0,
+    is      => 'ro',
+    isa     => Bool,
+    default => 0,
 );
 
-
 has lock_type => (
-    is        => 'ro',
-    isa       => Str,
-    default   => $PINTO_LOCK_TYPE_EXCLUSIVE,
-    init_arg  => undef,
+    is       => 'ro',
+    isa      => Str,
+    default  => $PINTO_LOCK_TYPE_EXCLUSIVE,
+    init_arg => undef,
 );
 
 #------------------------------------------------------------------------------
@@ -66,12 +62,12 @@ requires qw( execute repo );
 #------------------------------------------------------------------------------
 
 around BUILD => sub {
-    my ($orig, $self) = @_;
+    my ( $orig, $self ) = @_;
 
     # Inflate the stack into a real object.  As a side
     # effect, this also verifies that the stack exists.
 
-    my $stack = $self->repo->get_stack($self->stack);
+    my $stack = $self->repo->get_stack( $self->stack );
     $self->_set_stack($stack);
 
     return $self->$orig;
@@ -79,29 +75,27 @@ around BUILD => sub {
 
 #------------------------------------------------------------------------------
 
-
 around execute => sub {
-    my ($orig, $self, @args) = @_;
+    my ( $orig, $self, @args ) = @_;
 
     $self->repo->txn_begin;
     my $stack = $self->stack->start_revision;
 
-    my @ok = try   { $self->$orig(@args) }
-             catch { $self->repo->txn_rollback; throw $_ };
+    my @ok = try { $self->$orig(@args) } catch { $self->repo->txn_rollback; throw $_ };
 
-    if ($self->dry_run) {
+    if ( $self->dry_run ) {
         $self->notice('Dry run -- rolling back database');
         $self->repo->txn_rollback;
         $self->repo->clean_files;
     }
-    elsif ($stack->refresh->has_not_changed) {
+    elsif ( $stack->refresh->has_not_changed ) {
         $self->warning('No changes were actually made');
         $self->repo->txn_rollback;
     }
     else {
         my $msg_title = $self->generate_message_title(@ok);
-        my $msg = $self->compose_message(title => $msg_title, stack => $stack);
-        $stack->commit_revision(message => $msg);
+        my $msg = $self->compose_message( title => $msg_title, stack => $stack );
+        $stack->commit_revision( message => $msg );
 
         $self->result->changed;
         $self->repo->txn_commit;
@@ -113,17 +107,17 @@ around execute => sub {
 #------------------------------------------------------------------------------
 
 sub compose_message {
-    my ($self, %args) = @_;
+    my ( $self, %args ) = @_;
 
-    my $title   = $args{title} || '';
-    my $stack   = $args{stack} || throw 'Must specify a stack';
-    my $diff    = $args{diff}  || $stack->diff;
+    my $title = $args{title} || '';
+    my $stack = $args{stack} || throw 'Must specify a stack';
+    my $diff  = $args{diff}  || $stack->diff;
 
     return $self->message
-        if $self->has_message and is_not_blank($self->message);
+        if $self->has_message and is_not_blank( $self->message );
 
     return $title
-        if $self->has_message and is_blank($self->message);
+        if $self->has_message and is_blank( $self->message );
 
     return $title
         if $self->use_default_message;
@@ -131,13 +125,15 @@ sub compose_message {
     return $title
         if not is_interactive;
 
-    my $cm = Pinto::CommitMessage->new( title => $title,
-                                        stack => $stack, 
-                                        diff  => $diff );
+    my $cm = Pinto::CommitMessage->new(
+        title => $title,
+        stack => $stack,
+        diff  => $diff
+    );
+
+    my $message = $self->chrome->edit( $cm->to_string );
+    $message =~ s/^ [#] .* $//gmsx;    # Strip comments
 
-    my $message = $self->chrome->edit($cm->to_string);
-    $message =~ s/^ [#] .* $//gmsx; # Strip comments
-                                            
     throw 'Aborting due to empty commit message' if is_blank($message);
 
     return $message;
@@ -146,11 +142,11 @@ sub compose_message {
 #------------------------------------------------------------------------------
 
 sub generate_message_title {
-    my ($self, @items, $extra) = @_;
+    my ( $self, @items, $extra ) = @_;
 
     my $class    = ref $self;
     my ($action) = $class =~ m/ ( [^:]* ) $/x;
-    my $title    = "$action ". join(', ', @items) . ($extra ? " $extra" : '');
+    my $title    = "$action " . join( ', ', @items ) . ( $extra ? " $extra" : '' );
 
     return $title;
 }
@@ -172,7 +168,7 @@ Pinto::Role::Committable - Role for actions that commit changes to the repositor
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 AUTHOR
 
