@@ -3,7 +3,7 @@
 package Pinto::Role::Transactional;
 
 use Moose::Role;
-use MooseX::MarkAsMethods (autoclean => 1);
+use MooseX::MarkAsMethods ( autoclean => 1 );
 
 use Try::Tiny;
 
@@ -11,7 +11,7 @@ use Pinto::Util qw(throw);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -20,12 +20,11 @@ requires qw( execute repo );
 #------------------------------------------------------------------------------
 
 around execute => sub {
-    my ($orig, $self, @args) = @_;
+    my ( $orig, $self, @args ) = @_;
 
     $self->repo->txn_begin;
 
-    my $result = try   { $self->$orig(@args); $self->repo->txn_commit }
-                 catch { $self->repo->txn_rollback; throw $_          };
+    my $result = try { $self->$orig(@args); $self->repo->txn_commit } catch { $self->repo->txn_rollback; throw $_ };
 
     return $self->result;
 };
@@ -47,7 +46,7 @@ Pinto::Role::Transactional - Role for actions that are transactional
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 AUTHOR
 
