@@ -20,16 +20,16 @@ use Pinto::Repository;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #-------------------------------------------------------------------------------
 
 
-has root  => (
-   is       => 'ro',
-   isa      => Dir,
-   required => 1,
-   coerce   => 1,
+has root => (
+    is       => 'ro',
+    isa      => Dir,
+    required => 1,
+    coerce   => 1,
 );
 
 
@@ -49,20 +49,18 @@ has router => (
 );
 
 
-
 class_has default_port => (
-    is       => 'ro',
-    isa      => Int,
-    default  => $PINTO_SERVER_DEFAULT_PORT,
+    is      => 'ro',
+    isa     => Int,
+    default => $PINTO_SERVER_DEFAULT_PORT,
 );
 
-
 #-------------------------------------------------------------------------------
 
 sub BUILD {
     my ($self) = @_;
 
-    my $repo = Pinto::Repository->new(root => $self->root);
+    my $repo = Pinto::Repository->new( root => $self->root );
     $repo->assert_sanity_ok;
 
     return $self;
@@ -76,7 +74,7 @@ sub to_app {
 
     my $app = sub { $self->call(@_) };
 
-    if (my %auth_options = $self->auth_options) {
+    if ( my %auth_options = $self->auth_options ) {
 
         my $backend = delete $auth_options{backend}
             or carp 'No auth backend provided!';
@@ -85,8 +83,7 @@ sub to_app {
         print "Authenticating using $class\n" if is_interactive;
         Class::Load::load_class($class);
 
-        $app = Plack::Middleware::Auth::Basic->wrap($app,
-            authenticator => $class->new(%auth_options) );
+        $app = Plack::Middleware::Auth::Basic->wrap( $app, authenticator => $class->new(%auth_options) );
     }
 
     return $app;
@@ -96,12 +93,12 @@ sub to_app {
 
 
 sub call {
-    my ($self, $env) = @_;
+    my ( $self, $env ) = @_;
 
-    my $response = $self->router->route($env, $self->root);
+    my $response = $self->router->route( $env, $self->root );
 
     $response = $response->finalize
-      if blessed($response) && $response->can('finalize');
+        if blessed($response) && $response->can('finalize');
 
     return $response;
 }
@@ -123,7 +120,7 @@ Pinto::Server - Web interface to a Pinto repository
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 ATTRIBUTES
 
