@@ -7,35 +7,38 @@ use warnings;
 
 use Class::Load;
 
-use Pinto::Util qw(throw); 
+use Pinto::Util qw(throw);
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #-------------------------------------------------------------------------------
 
 
-
 sub make_spec {
-    my ($class, $arg) = @_;
+    my ( $class, $arg ) = @_;
 
     my $type = ref $arg;
     my $spec_class;
 
-    if (not $type) {
+    if ( not $type ) {
 
-      $spec_class = ($arg =~ m{/}x) ? 'Pinto::DistributionSpec'
-                                    : 'Pinto::PackageSpec';
+        $spec_class =
+            ( $arg =~ m{/}x )
+            ? 'Pinto::DistributionSpec'
+            : 'Pinto::PackageSpec';
     }
-    elsif (ref $arg eq 'HASH') {
+    elsif ( ref $arg eq 'HASH' ) {
 
-      $spec_class = (exists $arg->{author}) ? 'Pinto::DistributionSpec'
-                                            : 'Pinto::PackageSpec';
+        $spec_class =
+            ( exists $arg->{author} )
+            ? 'Pinto::DistributionSpec'
+            : 'Pinto::PackageSpec';
     }
     else {
 
-      throw "Don't know how to make spec from $arg";
+        throw "Don't know how to make spec from $arg";
     }
 
     Class::Load::load_class($spec_class);
@@ -59,7 +62,7 @@ Pinto::SpecFactory - Create Spec objects from strings
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 METHODS
 
