@@ -4,7 +4,7 @@ package Pinto::Store;
 
 use Moose;
 use MooseX::StrictConstructor;
-use MooseX::MarkAsMethods (autoclean => 1);
+use MooseX::MarkAsMethods ( autoclean => 1 );
 
 use Try::Tiny;
 use CPAN::Checksums;
@@ -13,7 +13,7 @@ use Pinto::Util qw(debug throw);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.084_02'; # VERSION
+our $VERSION = '0.087_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -22,23 +22,23 @@ with qw( Pinto::Role::FileFetcher );
 #------------------------------------------------------------------------------
 
 has repo => (
-   is         => 'ro',
-   isa        => 'Pinto::Repository',
-   weak_ref   => 1,
-   required   => 1,
+    is       => 'ro',
+    isa      => 'Pinto::Repository',
+    weak_ref => 1,
+    required => 1,
 );
 
 #------------------------------------------------------------------------------
 # TODO: Use named arguments here...
 
 sub add_archive {
-    my ($self, $origin, $destination) = @_;
+    my ( $self, $origin, $destination ) = @_;
 
-    throw "$origin does not exist"      if not -e $origin;
-    throw "$origin is not a file"       if not -f $origin;
+    throw "$origin does not exist" if not -e $origin;
+    throw "$origin is not a file"  if not -f $origin;
 
-    $self->fetch(from => $origin, to => $destination);
-    $self->update_checksums(directory => $destination->parent);
+    $self->fetch( from => $origin, to => $destination );
+    $self->update_checksums( directory => $destination->parent );
 
     return $self;
 
@@ -48,7 +48,7 @@ sub add_archive {
 # TODO: Use named arguments here...
 
 sub remove_archive {
-    my ($self, $archive_file) = @_;
+    my ( $self, $archive_file ) = @_;
 
     $self->remove_path( path => $archive_file );
 
@@ -60,7 +60,7 @@ sub remove_archive {
 #------------------------------------------------------------------------------
 
 sub remove_path {
-    my ($self, %args) = @_;
+    my ( $self, %args ) = @_;
 
     my $path = $args{path};
     throw "Must specify a path" if not $path;
@@ -69,7 +69,7 @@ sub remove_path {
 
     $path->remove or throw "Failed to remove path $path: $!";
 
-    while (my $dir = $path->parent) {
+    while ( my $dir = $path->parent ) {
         last if $dir->children;
         debug("Removing empty directory $dir");
         $dir->remove or throw "Failed to remove directory $dir: $!";
@@ -82,26 +82,25 @@ sub remove_path {
 #------------------------------------------------------------------------------
 
 sub update_checksums {
-    my ($self, %args) = @_;
+    my ( $self, %args ) = @_;
     my $dir = $args{directory};
 
     return 0 if $ENV{PINTO_NO_CHECKSUMS};
-    return 0 if not -e $dir; # Would be fishy!
-    
+    return 0 if not -e $dir;                # Would be fishy!
+
     my @children = $dir->children;
     return if not @children;
 
     my $cs_file = $dir->file('CHECKSUMS');
 
     if ( -e $cs_file && @children == 1 ) {
-        $self->remove_path(path => $cs_file);
+        $self->remove_path( path => $cs_file );
         return 0;
     }
 
     debug("Generating $cs_file");
 
-    try   { CPAN::Checksums::updatedir($dir) }
-    catch { throw "CHECKSUM generation failed for $dir: $_" };
+    try { CPAN::Checksums::updatedir($dir) } catch { throw "CHECKSUM generation failed for $dir: $_" };
 
     return $self;
 }
@@ -124,7 +123,7 @@ Pinto::Store - Storage for distribution archives
 
 =head1 VERSION
 
-version 0.084_02
+version 0.087_01
 
 =head1 DESCRIPTION
 
